@@ -1,44 +1,51 @@
 #!/bin/bash
 # Drupal7	(http://drupal.org)
 #	BuildScript for Plamo Linux 4.7
-#			by Jun Kuwamura <juk@linet.gr.jp> on 2011-05-03
+#			by Jun Kuwamura <juk@linet.gr.jp> on 2011-05-28
 # require:
 #	httpd-2.2.x
 #	php-5.3.x
 #	postgresql-8.4.x
 #
+# defaults
+SRC_URI=http://ftp.drupal.org/files/projects/drupal-7.2.tar.gz
+PO_URI=http://ftp.drupal.org/files/translations/7.x/drupal/drupal-7.1.ja.po
+PO_FILE=${PO_URI##*/}
 
+# try drush to install
 DRUSH_URI=http://ftp.drupal.org/files/projects/drush-7.x-4.4.tar.gz
-DRUSH_FILE=${SRC_URI##*/}
+DRUSH_FILE=${DRUSH_URI##*/}
 
 if [ ! -f $DRUSH_FILE ]; then
   wget -N $DRUSH_URI
-  tar xfz $DRUSH_FILE
+  tar xvfz $DRUSH_FILE
 fi
 
 export PATH=/opt/php5/bin:$PATH
 
-if [ ! -d drupal-7.0 ]; then
-  ./drush/drush dl drupal >& drush-dl-drupal.log
-  VERSION=`grep "Project drupal" drush-dl-drupal.log | sed -e s'/.*(\(.*\)).*/\1/'`
+if [ -d drupal-7.2 ]; then
+  VERSION=7.2
 else
-  VERSION=7.0
+./drush/drush dl drupal >& drush-dl-drupal.log
+VERSION=`grep "downloaded to" drush-dl-drupal.log | sed -e s'/.*(\(.*\)).*/\1/'`
 fi
 echo "VERSION = $VERSION"
 
-PAC_NAME=drupal-$VERSION
-echo "PAC_NAME = $PAC_NAME"
+if [ "$VERSION" != "" ]; then
+  PAC_NAME=drupal-$VERSION
+  echo "PAC_NAME = $PAC_NAME"
 
-#(cd $PAC_NAME; ../drush/drush dl ja > drush-dl-ja.log)
-#JVERS=`sed -e s'/.*(\(.*\)).*/\1/' drush-dl-ja.log`
-#echo "JVERS = $JVERS"
+  #(cd $PAC_NAME; ../drush/drush dl ja > drush-dl-ja.log)
+  #JVERS=`sed -e s'/.*(\(.*\)).*/\1/' drush-dl-ja.log`
+  #echo "JVERS = $JVERS"
+  
+  (cd $PAC_NAME/profiles/standard/translations/; \
+   wget -N $PO_URI )
 
-(cd $PAC_NAME/profiles/standard/translations/; \
- wget -N http://ftp.drupal.org/files/translations/7.x/drupal/drupal-7.0.ja.po )
-
-SRC_FILE=${PAC_NAME}.tar.gz
-echo $SRC_FILE
-tar cvfz $SRC_FILE $PAC_NAME
+  SRC_FILE=${PAC_NAME}.tar.gz
+  echo $SRC_FILE
+  tar cvfz $SRC_FILE $PAC_NAME
+fi
 
 #JAM_URI=http://downloads.sourceforge.net/drupal-jp/jamail-6.x-1.0.tgz
 #JAM_FILE=${JAM_URI##*/}
@@ -77,8 +84,11 @@ if [ ! -f $SRC_DIR/$SRC_FILE ]; then
   if [ ! -d $SRC_DIR ]; then
     mkdir -p $SRC_DIR
   fi
-  #( cd $SRC_DIR; wget $SRC_URI )
-  mv -v $SRC_FILE $SRC_DIR/
+  if [ "$VERSION" != "" ]; then
+    mv -v $SRC_FILE $SRC_DIR/
+  else
+    ( cd $SRC_DIR; wget $SRC_URI )
+  fi
 fi
 if [ ! -f $SRC_DIR/$JAM_FILE ]; then
   ( cd $SRC_DIR; wget $JAM_URI )
@@ -105,6 +115,7 @@ cd opt/htdocs
 tar xvfz $SRC_DIR/$SRC_FILE
 chmod -R o-w $PAC_NAME
 cd $PAC_NAME
+(cd profiles/standard/translations/; wget -N $PO_URI )
 
 if [ -f $CUSTOM_DIR/$PAT_FILE ]; then
   patch -p0 < $CUSTOM_DIR/$PAT_FILE
